"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getHashingImplementation = exports.HasherImplementation = void 0;
const native_file_hasher_1 = require("../hasher/native-file-hasher");
const workspace_root_1 = require("./workspace-root");
const child_process_1 = require("child_process");
const fs_1 = require("fs");
const path_1 = require("path");
var HasherImplementation;
(function (HasherImplementation) {
    HasherImplementation["Native"] = "Native";
    HasherImplementation["Git"] = "Git";
    HasherImplementation["Node"] = "Node";
})(HasherImplementation = exports.HasherImplementation || (exports.HasherImplementation = {}));
function getHashingImplementation() {
    try {
        if ((!process.env.NX_NON_NATIVE_HASHER ||
            process.env.NX_NON_NATIVE_HASHER != 'true') &&
            native_file_hasher_1.NativeFileHasher.available()) {
            return HasherImplementation.Native;
        }
        (0, child_process_1.execSync)('git rev-parse --is-inside-work-tree', {
            stdio: 'ignore',
            windowsHide: true,
        });
        // we don't use git based hasher when the repo uses git submodules
        if (!(0, fs_1.existsSync)((0, path_1.join)(workspace_root_1.workspaceRoot, '.git', 'modules'))) {
            return HasherImplementation.Git;
        }
        else {
            return HasherImplementation.Node;
        }
    }
    catch (_a) {
        return HasherImplementation.Node;
    }
}
exports.getHashingImplementation = getHashingImplementation;
//# sourceMappingURL=get-hashing-implementation.js.map